@@ -185,7 +185,7 @@
 #' @param y numeric vector that contains the flow depth (m or ft), if known.
 #' @param B1 numeric vector that contains the "bank-full width", if known.
 #' @param y1 numeric vector that contains the "bank-full depth", if known.
-#' @param T numeric vector that contains the temperature (degrees C or degrees
+#' @param Temp numeric vector that contains the temperature (degrees C or degrees
 #'   Fahrenheit), if known.
 #' @param units character vector that contains the system of units {options are
 #'   \code{SI} for International System of Units or \code{Eng} for English units
@@ -269,7 +269,7 @@
 #' @importFrom stats uniroot
 #'
 #' @export
-Manningpara <- function (Q = NULL, n = NULL, m = NULL, Sf = NULL, y = NULL, B1 = NULL, y1 = NULL, T = NULL, units = c("SI", "Eng")) {
+Manningpara <- function (Q = NULL, n = NULL, m = NULL, Sf = NULL, y = NULL, B1 = NULL, y1 = NULL, Temp = NULL, units = c("SI", "Eng")) {
 
 checks <- c(Q, n, m, Sf, y, B1, y1)
 
@@ -297,13 +297,13 @@ assert_that(isTRUE(any(c("SI", "Eng") %in% units)), msg = "The unit system has n
 if (units == "SI") {
 
 # use the temperature to determine the density & absolute and kinematic viscosities
-T <- ifelse(is.null(T), 20, T) # degrees C
+Temp <- ifelse(is.null(Temp), 20, Temp) # degrees C
 
-assert_that(qtest(T, "N+(0,)"), msg = "Either T is equal to or less than 0 C, NA, NaN, Inf, -Inf, empty, or a string. The equation is valid only for temperatures greater than 0 C / 32 F. Please try again.")
+assert_that(qtest(Temp, "N+(0,)"), msg = "Either Temp is equal to or less than 0 C, NA, NaN, Inf, -Inf, empty, or a string. The equation is valid only for temperatures greater than 0 C / 32 F. Please try again.")
 # only process with specified, finite values and provide an error message if the check fails
 
 # create a numeric vector with the units of degrees Celsius
-T_C <- set_units(T, "degree_C")
+T_C <- set_units(Temp, "degree_C")
 
 
 # create a numeric vector to convert from degrees Celsius to Kelvin
@@ -316,10 +316,10 @@ units(T_K) <- make_units(K)
 
 # create viscosities based on temperatures
 # saturated liquid density at given temperature in degrees Celsius (SI units)
-rho_SI <- density_water(T, "SI")
+rho_SI <- density_water(Temp, "SI")
 
 # absolute or dynamic viscosity at given temperature in degrees Celsius and density of rho (SI units)
-mu_SI <- dyn_visc_water(T, "SI")
+mu_SI <- dyn_visc_water(Temp, "SI")
 
 # kinematic viscosity at given temperature in degrees Celsius and density of rho (SI units)
 nu_SI <- kin_visc_water(rho_SI, mu_SI, rho_units = "kg/m^3", mu_units = "Pa*s or kg/m/s")
@@ -352,12 +352,12 @@ result_units <- c("m", "m^2", "m", "m", "m", "m", "m", "m/s", "m^3/s", "dimensio
 } else if (units == "Eng") {
 
 # use the temperature to determine the density & absolute and kinematic viscosities
-T <- ifelse(is.null(T), 68, T) # degrees F
+Temp <- ifelse(is.null(Temp), 68, Temp) # degrees F
 
-assert_that(qtest(T, "N+(32,)"), msg = "Either T is equal to or less than 32 F, NA, NaN, Inf, -Inf, empty, or a string. The equation is valid only for temperatures greater than 32 F / 0 C. Please try again.")
+assert_that(qtest(Temp, "N+(32,)"), msg = "Either Temp is equal to or less than 32 F, NA, NaN, Inf, -Inf, empty, or a string. The equation is valid only for temperatures greater than 32 F / 0 C. Please try again.")
 # only process with specified, finite values and provide an error message if the check fails
 
-T_F <- T
+T_F <- Temp
 
 # create a numeric vector with the units of degrees Fahrenheit
 T_F <- set_units(T_F, "degree_F")
@@ -373,11 +373,11 @@ units(T_K) <- make_units(K)
 
 # create viscosities based on temperatures
 # saturated liquid density at given temperature in degrees Fahrenheit (US Customary units)
-rho_Eng <- density_water(T, "Eng", Eng_units = "slug/ft^3")
+rho_Eng <- density_water(Temp, "Eng", Eng_units = "slug/ft^3")
 
 
 # absolute or dynamic viscosity at given temperature in degrees Fahrenheit and density of rho (US Customary units)
-mu_Eng <- dyn_visc_water(T, "Eng", Eng_units = "slug/ft/s")
+mu_Eng <- dyn_visc_water(Temp, "Eng", Eng_units = "slug/ft/s")
 
 
 # kinematic viscosity at given temperature in degrees Fahrenheit and density of rho (US Customary units)
