@@ -1,7 +1,5 @@
 ## ---- warning = FALSE, message = FALSE, tidy = TRUE---------------------------
 
-# Example 1 (Caprani Reference)
-
 library("iemisc")
 import::from(ramify, mat)
 
@@ -18,6 +16,3 @@ SP
 ## ---- echo = FALSE, out.width = '100%'----------------------------------------
 linguisticsdown::include_graphics2("secprop_gnu-octave_figure.png")
 
-## ---- echo = FALSE, out.width = '100%'----------------------------------------
-linguisticsdown::include_graphics2("https://i.creativecommons.org/l/by-sa/4.0/88x31.png")
-
